@@ -191,6 +191,14 @@ _check_symbol(mei_node_t *p)
             iok += _check_symbol(p->type->funcx.op[1]);
             return iok;
 
+        case FUNC3:
+                bft_error(__FILE__, __LINE__, 0, "not implemented yet \n");
+		break;
+
+        case FUNC4:
+                bft_error(__FILE__, __LINE__, 0, "not implemented yet \n");
+		break;
+
         case OPR:
 
             switch (p->type->opr.oper)
@@ -223,7 +231,7 @@ _check_symbol(mei_node_t *p)
             case UMINUS:
                 return _check_symbol(p->type->opr.op[0]);
 
-            case UNOT:
+            case '!':
                 return _check_symbol(p->type->opr.op[0]);
 
             default:
@@ -271,6 +279,14 @@ _evaluate(mei_node_t *p)
             f2 = (mei_hash_table_lookup(p->ht, p->type->funcx.name))->data->f2;
             return f2(_evaluate(p->type->funcx.op[0]), _evaluate(p->type->funcx.op[1]));
 
+        case FUNC3:
+                bft_error(__FILE__, __LINE__, 0, "not implemented\n");
+		break;
+
+        case FUNC4:
+                bft_error(__FILE__, __LINE__, 0, "not implemented\n");
+		break;
+
         case OPR:
 
             switch(p->type->opr.oper)
@@ -339,7 +355,7 @@ _evaluate(mei_node_t *p)
                 case '>':
                     return _evaluate(p->type->opr.op[0]) > _evaluate(p->type->opr.op[1]);
 
-                case UNOT:
+                case '!':
                     return ! _evaluate(p->type->opr.op[0]);
 
                 case GE:
@@ -812,7 +828,6 @@ int
 mei_tree_find_symbol(mei_tree_t *const ev, const char *const str)
 {
     int i;
-    size_t l;
 
     assert(ev != NULL);
     assert(str != NULL);
